Module fetcher

Module fetcher 

Re-exports

pub use service::FetcherService;
pub use state::ActiveFetch;
pub use state::Config;
pub use state::FetcherState;
pub use state::MaxQueueSize;
pub use state::Queue;
pub use state::QueueIter;
pub use state::QueuedFetch;

Modules

service
state
Logical state for Git fetches happening in the node.

Enums

RefsToFetch
Represents references to fetch, in the context of a repository.