Fetch

Enum Fetch 

pub enum Fetch {
    Started {
        rid: RepoId,
        from: NodeId,
        refs: RefsToFetch,
        timeout: Duration,
    },
    AlreadyFetching {
        rid: RepoId,
        from: NodeId,
    },
    QueueAtCapacity {
        rid: RepoId,
        from: NodeId,
        refs: RefsToFetch,
        timeout: Duration,
        capacity: usize,
    },
    Queued {
        rid: RepoId,
        from: NodeId,
    },
}
Events that occur when a repository is requested to be fetched.

Variants



Started

The fetch can be started by the caller.

Fields

rid: RepoId

The repository to be fetched.

from: NodeId

The node to fetch from.

refs: RefsToFetch

The references to be fetched.

timeout: Duration

The timeout for the fetch process.



AlreadyFetching

The repository is already being fetched from the given node.

Fields

rid: RepoId

The repository being actively fetched.

from: NodeId

The node being fetched from.



QueueAtCapacity

The queue for the given node is at capacity, and can no longer accept any more fetch requests.

Fields

rid: RepoId

The rejected repository.

from: NodeId

The node who’s queue is at capacity.

refs: RefsToFetch

The references expected to be fetched.

timeout: Duration

The timeout for the fetch process.

capacity: usize

The capacity of the queue.



Queued

The fetch was queued for later processing.

Fields

rid: RepoId

The repository to be fetched.

from: NodeId

The node to fetch from.