ActiveFetch

Struct ActiveFetch 

pub struct ActiveFetch {
    pub from: NodeId,
    pub refs: RefsToFetch,
}
An active fetch represents a repository being fetched by a particular node.

Fields

from: NodeIdrefs: RefsToFetch

Implementations

Source

impl ActiveFetch

pub fn from(&self) -> &NodeId

The node from which the repository is being fetched.

pub fn refs(&self) -> &RefsToFetch

The set of references that fetch is being performed for.