FetchConfig

Struct FetchConfig 

pub struct FetchConfig { /* private fields */ }
Configuration options for tuning the fetch process.

Note that these are not used directly by FetcherState, but are maintained within the state so that the options can be tracked across queued fetches.

Implementations

Source

impl FetchConfig

pub fn new() -> Self

Construct the default FetchConfig.

pub fn with_timeout(self, timeout: Duration) -> Self

Set the FetchConfig::timeout to the given time::Duration.

pub fn with_fetch_config(self, config: Config) -> Self

pub fn with_minimum_feature_level(self, feature_level: FeatureLevel) -> Self

Set the minimum feature level, within the FetchConfig::fetch_config, to the given FeatureLevel.

pub fn timeout(&self) -> Duration

Return the timeout duration configured for this fetch.

pub fn fetch_config(&self) -> Config

Return the radicle_fetch::Config configured for this fetch.