Queue

Struct Queue 

pub struct Queue { /* private fields */ }
A queue for keeping track of fetches.

It ensures that the queue contains unique items for fetching, and does not exceed the provided maximum capacity.

Implementations

Source

impl Queue

pub fn iter<'a>(&'a self) -> QueueIter<'a>

Return an iterator over the queued fetches.