pub struct QueuedFetch {
pub rid: RepoId,
pub refs: RefsToFetch,
pub timeout: Duration,
}Expand description
A fetch that is waiting to be processed, in the fetch queue.
Fields
rid: RepoIdThe repository that will be fetched.
refs: RefsToFetchThe references that the fetch is being performed for.
timeout: DurationThe timeout given for the fetch request.