Module command

Module command 

Structs

Responder
A Responder returns results after processing a service Command.

Enums

Command
Commands sent to the service by the operator.
Error
An error that occurred when processing a service Command.

Type Aliases

QueryState
Function used to query internal service state.
Result
A result returned from processing a Command.