pub enum Fetch {
Started {
rid: RepoId,
from: NodeId,
refs: RefsToFetch,
timeout: Duration,
},
AlreadyFetching {
rid: RepoId,
from: NodeId,
},
QueueAtCapacity {
rid: RepoId,
from: NodeId,
refs: RefsToFetch,
timeout: Duration,
capacity: usize,
},
Queued {
rid: RepoId,
from: NodeId,
},
}Expand description
Events that occur when a repository is requested to be fetched.
Variants
Started
The fetch can be started by the caller.
Fields

refs: RefsToFetchThe references to be fetched.
AlreadyFetching
The repository is already being fetched from the given node.
QueueAtCapacity
The queue for the given node is at capacity, and can no longer accept any more fetch requests.
Fields

refs: RefsToFetchThe references expected to be fetched.
Queued
The fetch was queued for later processing.